@@ -13,6 +13,11 @@ from fog.clustering.pairwise import (
     pairwise_connected_components
 )
 from fog.clustering.passjoin import passjoin
+from fog.clustering.ppjoin import (
+    all_pairs,
+    ppjoin,
+    ppjoin_plus
+)
 from fog.clustering.quickjoin import quickjoin
 from fog.clustering.sorted_neighborhood import (
     sorted_neighborhood,
