@@ -1,7 +1,12 @@
 from fog.metrics.cosine import (
     cosine_similarity,
     sparse_cosine_similarity,
-    sparse_dot_product
+    sparse_dot_product,
+    binary_cosine_similarity,
+    sparse_binary_cosine_similarity,
+)
+from fog.metrics.dice import (
+    dice_coefficient
 )
 from fog.metrics.jaccard import (
     jaccard_similarity,
